@ECHO OFF
SET AUTHOR=Mikhail Petrushin aka Fifonik aka Misha v.3
SET LINK=http://fifonik.com/blog/sd-upscale
SET VERSION=1.13

REM -- Prepare the Command Processor --
SETLOCAL ENABLEEXTENSIONS ENABLEDELAYEDEXPANSION

REM -- Constants --
SET WORK_DIR=%~dp0
SET CODECS_SUBDIR=codecs
SET UPSCALE_TEMPLATES_SUBDIR=upscale
SET UPSCALE_VCF=%WORK_DIR%\%UPSCALE_TEMPLATES_SUBDIR%\Upscale.vcf
SET DESHAKER_TEMPLATES_SUBDIR=deshaker
SET DESHAKER_VCF=%WORK_DIR%\%DESHAKER_TEMPLATES_SUBDIR%\Deshaker.vcf

REM -- Defaulting  --
SET "DEBUG="
SET VDUB=%ProgramFiles(x86)%\VirtualDub\vdub.exe
SET TEMP_DIR=%TEMP%\Upscale
SET DELETE_SRC=FALSE
SET CODEC=HuffYUV
SET CODEC_PRESET=Default
SET CODEC_TEMP=HuffYUV
SET CODEC_TEMP_PRESET=Default
SET MODE=ud
SET "OUTPUT_DIR="
SET "OUTPUT_SUFFIX="
SET UPSCALE=Default
SET DESHAKER=Default
SET "DESHAKER_LOG="

IF [%1]==[] GOTO :usage

CALL :parse_params %*

IF NOT [%DEBUG%]==[] CALL :debug_info

IF NOT EXIST "%VDUB%" GOTO :vdub_not_found

IF [%MODE%]==[u] GOTO :end_mode_check
IF [%MODE%]==[ud] GOTO :end_mode_check
REM IF [%MODE%]==[d] GOTO :end_mode_check
REM IF [%MODE%]==[du] GOTO :end_mode_check
GOTO :unknown_mode
:end_mode_check

SET _dummy=%MODE:u=%
IF [%_dummy%]==[%MODE%] GOTO :end_upscale_check
IF NOT EXIST "%UPSCALE_VCF%" GOTO :upscale_vcf_not_found
SET UPSCALE_SOURCE=%WORK_DIR%\%UPSCALE_TEMPLATES_SUBDIR%\%UPSCALE%\Source.avs
IF NOT EXIST "%UPSCALE_SOURCE%" GOTO :upscale_avs_not_found
:end_upscale_check

SET _dummy=%MODE:d=%
IF [%_dummy%]==[%MODE%] GOTO :end_deshaker_check
IF NOT EXIST "%DESHAKER_VCF%" GOTO :deshaker_vcf_not_found
SET DESHAKER_1_PASS_VCF=%WORK_DIR%\%DESHAKER_TEMPLATES_SUBDIR%\%DESHAKER%\1.vcf
SET DESHAKER_2_PASS_VCF=%WORK_DIR%\%DESHAKER_TEMPLATES_SUBDIR%\%DESHAKER%\2.vcf
IF NOT EXIST "%DESHAKER_1_PASS_VCF%" GOTO :deshaker_1st_pass_template_not_found
IF NOT EXIST "%DESHAKER_2_PASS_VCF%" GOTO :deshaker_2nd_pass_template_not_found
IF [%DESHAKER_LOG%]==[] SET DESHAKER_LOG=%TEMP_DIR%\Deshaker.log
CALL :debug "%DESHAKER_VCF%" "%DESHAKER_1_PASS_VCF%" "%DESHAKER_2_PASS_VCF%" "%DESHAKER_LOG%"
:end_deshaker_check


IF [%CODEC%]==[] GOTO :end_codec_check
SET CODEC_VCF=%WORK_DIR%\%CODECS_SUBDIR%\%CODEC%\%CODEC_PRESET%.vcf
IF NOT EXIST "%CODEC_VCF%" GOTO :codec_not_found
:end_codec_check


IF [%CODEC_TEMP%]==[] GOTO :end_codec_temp_check
SET CODEC_TEMP_VCF=%WORK_DIR%\%CODECS_SUBDIR%\%CODEC_TEMP%\%CODEC_TEMP_PRESET%.vcf
IF NOT EXIST "%CODEC_TEMP_VCF%" GOTO :codec_temp_not_found
:end_codec_temp_check


IF NOT [%OUTPUT_SUFFIX%]==[] GOTO :end_output_suffix_defaulting
IF [%CODEC%]==[] (
	SET OUTPUT_SUFFIX=_uncompressed
	GOTO :end_output_suffix_defaulting
)
SET OUTPUT_SUFFIX=_%CODEC%
IF [%CODEC_PRESET%]==[] GOTO :end_output_suffix_defaulting
IF [%CODEC_PRESET%]==[Default] GOTO :end_output_suffix_defaulting
SET OUTPUT_SUFFIX=%OUTPUT_SUFFIX%_%CODEC_PRESET%
:end_output_suffix_defaulting

SET /A fail_count=0
ECHO Processing %files_count% files (%files_size_mb% MB)

MKDIR "%TEMP_DIR%" >nul 2>&1

CALL :debug main_loop
SET /A i=0
SET /A processed_size_b=0
SET /A processed_size_mb=0
FOR %%A IN (%*) DO (
	CALL :main_loop_body "%%~A"
)
CALL :debug end_main_loop

RMDIR /S /Q "%TEMP_DIR%" >nul 2>&1

TITLE %COMSPEC%
IF %fail_count% NEQ 0 (
	ECHO %fail_count% files was not processed.
	PAUSE
)
GOTO :EOF




:main_loop_body
SET /A i+=1
IF %i% GEQ %files_offset% (
	CALL :debug "%~1"
	CALL :do_process_file "%~1"
) ELSE (
	CALL :debug Skip
)
GOTO :EOF




:do_process_file
SET PROJECT_SRC=%~f1
IF [%OUTPUT_DIR%] == [] (
	SET PROJECT_DEST=%~dp1%~n1%OUTPUT_SUFFIX%.avi
) ELSE (
	SET PROJECT_DEST=%OUTPUT_DIR%\%~n1%OUTPUT_SUFFIX%.avi
)

IF NOT EXIST "%PROJECT_SRC%" ECHO File "%~1" does not exist.&GOTO :do_process_file_end
SET /A _cur=%i%-%files_offset%+1
SET /A _size_b=%~z1
SET /A _size_mb=%~z1/1048576
SET /A processed_size_b+=%_size_b%
SET /A processed_size_mb+=%_size_mb%
SET /A _percentage=100*%processed_size_mb%/%files_size_mb%
SET "_debug=%_size_b% %_size_mb% %processed_size_b% %processed_size_mb% %files_size% %files_size_mb% %_percentage%"
REM ECHO DEBUG %_debug%
ECHO Processing file "%PROJECT_SRC%" ^(%_size_mb% MB^) [%_percentage%%%/%processed_size_mb%/%files_size_mb% MB] [%_cur%/%files_count%] 

SET _first=%MODE:~0,1%
SET _second=%MODE:~1,1%
CALL :debug first step: '%_first%, second step: '%_second%'

:: Options for ONE-STEP process
SET "_temp_file="
SET _dest=%PROJECT_DEST%
SET _codec_first_step=%CODEC_VCF%
SET "_codec_second_step="

IF [%_second%]==[] GOTO :do_process_file_steps
:: Options for TWO-STEPS process
SET _temp_file=%TEMP_DIR%\%~n1.avi
SET _dest=%_temp_file%
SET _codec_first_step=%CODEC_TEMP_VCF%
SET _codec_second_step=%CODEC_VCF%

:do_process_file_steps

:do_process_file_first_step
CALL :do_step %_first% "%PROJECT_SRC%" "%_dest%" "%_codec_first_step%"
IF NOT [%ERRORLEVEL%]==[0] (
	SET /A "fail_count+=1"
	GOTO :do_process_file_steps_end
)
:do_process_file_first_step_end

:do_process_file_second_step
IF [%_second%]==[] GOTO :do_process_file_second_step_end
CALL :do_step %_second% "%_dest%" "%PROJECT_DEST%" "%_codec_second_step%"
SET _errorlevel=%ERRORLEVEL%
IF NOT [%_temp_file%]==[] DEL /Q "%_temp_file%" >nul
IF NOT [%_errorlevel%]==[0] (
	SET /A "fail_count+=1"
	GOTO :do_process_file_steps_end
)
:do_process_file_second_step_end

:do_process_file_delete_src
IF NOT [%DELETE_SRC%]==[TRUE] GOTO :do_process_file_delete_src_end
DEL /Q "%PROJECT_SRC%" >nul
ECHO Source deleted.
:do_process_file_delete_src_end

:do_process_file_steps_end
ECHO Processing file complete ^(%_percentage%%%^)
ECHO.

:do_process_file_end
GOTO :EOF




:do_step
SETLOCAL
IF [%1]==[u] CALL :do_upscale "%~2" "%~3" "%~4"
IF [%1]==[d] CALL :do_deshake "%~2" "%~3" "%~4"
ENDLOCAL & EXIT /B %ERRORLEVEL%
GOTO :EOF




:do_upscale
SETLOCAL
TITLE Upscaling %~nx1
CALL :debug upscale '%~1' to '%~2' ^(using codec '%~3'^)

:: Prepare source file (avs)
SET _upscale_src=%TEMP_DIR%\%~n1.avs
COPY /Y "%UPSCALE_SOURCE%" "%_upscale_src%" >nul 2>&1
CALL :modify_file "%_upscale_src%" "__source__" "%~1"

:: Prepare vcf file
SET _upscale_vcf=%TEMP_DIR%\%~n1_upscale.vcf
COPY /Y "%UPSCALE_VCF%" "%_upscale_vcf%" >nul 2>&1
IF NOT [%~3]==[] (CALL :modify_file "%_upscale_vcf%" "__video_codec__" "::%~3")

:: execute VDub
CALL :vdub "%_upscale_src%" "%~2" "%_upscale_vcf%" Upscaling
SET _errorlevel=%ERRORLEVEL%

IF NOT [%DEBUG%]==[] PAUSE

:: Delete temporary files
DEL /Q "%_upscale_src%" > nul
DEL /Q "%_upscale_vcf%" >nul 2>&1
DEL /Q "%PROJECT_SRC%.ffv0cache" >nul 2>&1
DEL /Q "%PROJECT_SRC%.ffindex" >nul 2>&1
ENDLOCAL & EXIT /B %_errorlevel%
GOTO :EOF




:do_deshake
SETLOCAL
TITLE Deshaking %~nx1
CALL :debug deshake '%~1' to '%~2' ^(using codec '%~3'^)

:: Prepare vcf file
SET _deshake_vcf=%TEMP_DIR%\%~n1_deshake.vcf
COPY /Y "%DESHAKER_VCF%" "%_deshake_vcf%" >nul 2>&1

IF NOT [%~3]==[] (CALL :modify_file "%_deshake_vcf%" "__video_codec__" "::%~3")

CALL :modify_file "%_deshake_vcf%" "__deshaker_1_pass_options__" "::%DESHAKER_1_PASS_VCF%"
CALL :modify_file "%_deshake_vcf%" "__deshaker_2_pass_options__" "::%DESHAKER_2_PASS_VCF%"
CALL :modify_file "%_deshake_vcf%" "__deshaker_log__" "%DESHAKER_LOG:\=\\%"

:: execute VDub
CALL :vdub "%~1" "%~2" "%_deshake_vcf%" Deshaking
SET _errorlevel=%ERRORLEVEL%

IF NOT [%DEBUG%]==[] PAUSE

:: Delete temporary files
DEL /Q "%_deshake_vcf%" >nul 2>&1
DEL /Q "%DESHAKER_LOG%" >nul 2>&1
ENDLOCAL & EXIT /B %_errorlevel%
GOTO :EOF




:modify_file
:: examples
::   call :modify_file "filespec" "find-str" "replace-str"
::   call :modify_file "filespec" "find-str" "::replace-filespec"
SETLOCAL
SET _temp_filespec=%TEMP_DIR%\Upscale.tmp
CALL :subst2 "%~1" "%~2" "%~3" > "%_temp_filespec%"
MOVE /Y "%_temp_filespec%" "%~1" >nul 2>&1
ENDLOCAL
GOTO :EOF




:subst2
:: examples:
::   call :subst2 "filespec" "find-str" "replace-str"
::   call :subst2 "filespec" "find-str" "::replace-filespec"
SETLOCAL
SET _repl=%~3
IF [%_repl:~0,2%]==[::] GOTO :subst2_file

FOR /f "eol= tokens=* delims=" %%f IN (%~1) DO (
	SET "_line=%%f"
	SET _line=!_line:%~2=%_repl%!
	ECHO !_line!
)
GOTO :end_subst2

:subst2_file
SET _filespec=%_repl:~2%
FOR /f "eol= tokens=* delims=" %%f IN (%~1) DO (
	SET "_line=%%f"
	SET _dummy=!_line:%~2=!
	IF [!_dummy!]==[!_line!] (ECHO !_line!) ELSE (TYPE "%_filespec%")
)

:end_subst2
ENDLOCAL
GOTO :EOF




:vdub
ECHO %4...
SET _begin=%time%
"%VDUB%" /min /x /i %3 %1 %2 > nul

IF [%ERRORLEVEL%]==[0] GOTO :vdub_ok
ECHO %4 failed.
EXIT /B 1
GOTO :EOF

:vdub_ok
CALL :tdiff %_begin% %time%
ECHO %4 complete ^(execution time %_tdiff%^)
EXIT /B 0
GOTO :EOF




:debug
IF NOT [%DEBUG%]==[] ECHO %*
GOTO :EOF




:debug_info
ECHO.
ECHO VDUB '%VDUB%'
ECHO TEMP_DIR '%TEMP_DIR%'
ECHO WORK_DIR '%WORK_DIR%'

ECHO UPSCALE_TEMPLATES_SUBDIR '%UPSCALE_TEMPLATES_SUBDIR%'
ECHO UPSCALE_VCF '%UPSCALE_VCF%'
ECHO UPSCALE '%UPSCALE%'

ECHO DESHAKER_TEMPLATES_SUBDIR '%DESHAKER_TEMPLATES_SUBDIR%'
ECHO DESHAKER_VCF '%DESHAKER_VCF%'
ECHO DESHAKER '%DESHAKER%'

ECHO CODECS_SUBDIR '%CODECS_SUBDIR%'
ECHO CODEC '%CODEC%'
ECHO CODEC_PRESET '%CODEC_PRESET%'
ECHO CODEC_TEMP '%CODEC_TEMP%'
ECHO CODEC_TEMP_PRESET '%CODEC_TEMP_PRESET%'

ECHO MODE '%MODE%'
ECHO DELETE_SRC '%DELETE_SRC%'
ECHO OUTPUT_DIR '%OUTPUT_DIR%'
ECHO OUTPUT_SUFFIX '%OUTPUT_SUFFIX%'
ECHO.
GOTO :EOF




:usage
ECHO Helper script for upscaling SD video to HD and deshaking it.
ECHO See Readme.txt for details and installation instructions.
ECHO Version: %VERSION%
ECHO Author:  %AUTHOR%
ECHO          %LINK%
ECHO.
ECHO Usage:
ECHO   %0 [options] file [file2] [file3] [...]
ECHO.
ECHO Options:
ECHO   --help                         Show this help
ECHO   --vdub filespec                Path to vdub.exe
ECHO                                  Default: %%ProgramFiles(x86)%%\VirtualDub\vdub.exe
ECHO   --temp dir                     Temp directory
ECHO                                  Default: %%TEMP%%\Upscale
ECHO   --upscale preset               Upscale preset
ECHO                                  See sub-directory "%UPSCALE_TEMPLATES_SUBDIR%"
ECHO   --deshaker preset              Deshaker preset
ECHO                                  See sub-directory "%DESHAKER_TEMPLATES_SUBDIR%"
ECHO   --deshaker-log filespec        Path to deshaker log file
ECHO                                  Default: %%TEMP%%\Upscale\Deshaker.log
ECHO   --codec name                   Codec for the last step
ECHO                                  See sub-directory "%CODECS_SUBDIR%"
ECHO                                  Default: HuffYUV ^(lossless^)
ECHO   --codec-preset preset          Codec's preset for the last step
ECHO                                  See directory "%CODECS_SUBDIR%\^<codec^>\"
ECHO   --codec-temp name              Codec for the first step
ECHO                                  See sub-directory "%CODECS_SUBDIR%"
ECHO                                  Default: HuffYUV ^(lossless^)
ECHO   --codec-temp-preset preset     Codec's preset for the first step
ECHO                                  See directory "%CODECS_SUBDIR%\^<codec^>\"
ECHO   --output-dir dir               Directory for output files
ECHO                                  Default: source directory
ECHO   --output-suffix suffix         Suffix for output files
ECHO                                  Default: "_^<codec^>_^<codec-preset^>"
ECHO   --delete-src                   Delete source file after processing
ECHO                                  Default: source files will NOT be deleted
ECHO   --mode (u^|ud)
ECHO        u                         Upscale only
ECHO        ud                        Upscale then deshake [default]
EXIT /B 0
GOTO :EOF




:vdub_not_found
ECHO File %VDUB% does not exist.
ECHO   Use --vdub filespec option to specify path to vdub.exe
GOTO :EOF




:upscale_vcf_not_found
ECHO File %UPSCALE_VCF% does not exist.
GOTO :EOF




:upscale_avs_not_found
ECHO Unknown upscale preset "%UPSCALE%"
ECHO   For list of available upscale presets check sub-directory %UPSCALE_TEMPLATES_SUBDIR%.
IF NOT EXIST %WORK_DIR%\%UPSCALE_TEMPLATES_SUBDIR%\%UPSCALE%\ (
	ECHO   Directory %UPSCALE_TEMPLATES_SUBDIR%\%UPSCALE% does not exist.
	GOTO :EOF
)
IF NOT EXIST %WORK_DIR%\%UPSCALE_TEMPLATES_SUBDIR%\%UPSCALE%\Source.avs (
	ECHO   File %UPSCALE_TEMPLATES_SUBDIR%\%UPSCALE%\Source.avs does not exist.
	GOTO :EOF
)
GOTO :EOF




:deshaker_vcf_not_found
ECHO File %DESHAKER_VCF% does not exist.
GOTO :EOF




:deshaker_1st_pass_template_not_found
:deshaker_2nd_pass_template_not_found
ECHO Unknown deshaker preset "%DESHAKER%"
ECHO   For list of available deshaker presets check sub-directory %DESHAKER_TEMPLATES_SUBDIR%.
IF NOT EXIST %WORK_DIR%\%DESHAKER_TEMPLATES_SUBDIR%\%DESHAKER%\ (
	ECHO   Directory %DESHAKER_TEMPLATES_SUBDIR%\%DESHAKER% does not exist.
	GOTO :EOF
)
IF NOT EXIST %WORK_DIR%\%DESHAKER_TEMPLATES_SUBDIR%\%DESHAKER%\1.vcf (
	ECHO   File %DESHAKER_TEMPLATES_SUBDIR%\%DESHAKER%\1.vcf does not exist.
	GOTO :EOF
)
IF NOT EXIST %WORK_DIR%\%DESHAKER_TEMPLATES_SUBDIR%\%DESHAKER%\2.vcf (
	ECHO   File %DESHAKER_TEMPLATES_SUBDIR%\%DESHAKER%\2.vcf does not exist.
	GOTO :EOF
)
GOTO :EOF




:unknown_mode
ECHO Unknown mode '%MODE%' is specified.
ECHO   Supported modes are: 'ud' ^(default^) and 'u'.
GOTO :EOF




:codec_not_found
CALL :codec_not_found_msg "%CODEC%" "%CODEC_PRESET%"
GOTO :EOF




:codec_temp_not_found
CALL :codec_not_found_msg "%CODEC_TEMP%" "%CODEC_TEMP_PRESET%"
GOTO :EOF




:codec_not_found_msg
ECHO Unknown codec "%~1"
ECHO   For list of available codecs check sub-directory %CODECS_SUBDIR%.
ECHO   For list of codec's preset check sub-directory %CODECS_SUBDIR%\%~1.
IF NOT EXIST %WORK_DIR%\%CODECS_SUBDIR%\%~1\ (
	ECHO   Directory %CODECS_SUBDIR%\%~1% does not exist.
	GOTO :EOF
)
IF NOT EXIST %WORK_DIR%\%CODECS_SUBDIR%\%~1\%~2.vcf (
	ECHO   File %CODECS_SUBDIR%\%~1\%~2.vcf does not exist.
	GOTO :EOF
)
GOTO :EOF




:: tdiff source: http://ss64.com/nt/syntax-tdiff.html
:tdiff
SETLOCAL
:: Convert start and end times to hundredths of a second
CALL :s_calc_timecode %1
SET _start_timecode=%errorlevel%

CALL :s_calc_timecode %2
SET _stop_timecode=%errorlevel%

:: Calculate the difference in hundredths
SET /a _diff_timecode=_stop_timecode - _start_timecode

:: Midnight rollover
IF %_diff_timecode% LSS 0 SET /a _diff_timecode+=(24 * 60 * 60 * 100)
REM ECHO %_diff_timecode% hundredths of a second

:: Split out Hours, Mins etc and return the result
SET /a hs=_diff_timecode %% 100
SET /a _diff_timecode/=100

SET /a ss=_diff_timecode %% 60
SET /a _diff_timecode/=60
SET /a mm=_diff_timecode %% 60
SET /a _diff_timecode/=60
SET /a hh=_diff_timecode

SET hh=0%hh%
SET mm=0%mm%
SET ss=0%ss%
SET hs=0%hs%

SET _tdiff=%hh:~-2%:%mm:~-2%:%ss:~-2%.%hs:~-2%

REM ECHO HH:MM:ss.hs
REM ECHO %_tdiff%

ENDLOCAL & SET _tdiff=%_tdiff%
GOTO :EOF




:s_calc_timecode
:: Remove delimiters and convert to hundredths of a second.
SETLOCAL

FOR /f "usebackq tokens=1,2,3,4 delims=:." %%a IN ('%1') DO (
	SET hh=00%%a
	SET mm=00%%b
	SET ss=00%%c
	SET hs=00%%d
)
SET hh=%hh:~-2%
SET mm=%mm:~-2%
SET ss=%ss:~-2%
SET hs=%hs:~-2%
SET /a hh=((%hh:~0,1% * 10) + %hh:~1,1%) * 60 * 60 * 100
SET /a mm=((%mm:~0,1% * 10) + %mm:~1,1%) * 60 * 100
SET /a ss=((%ss:~0,1% * 10) + %ss:~1,1%) * 100
SET /a hs=((%hs:~0,1% * 10) + %hs:~1,1%)

SET /a _timecode=hh + mm + ss + hs

ENDLOCAL & EXIT /b %_timecode%
GOTO :EOF




:parse_params
SET /A files_offset=1
SET /A files_count=0
SET /A files_size=0
SET /A files_size_mb=0
CALL :debug parse_params_loop
:parse_params_loop
CALL :debug %1
IF [%1]==[--help] GOTO :usage
IF [%1]==[--temp] (
	SET TEMP_DIR=%~2
	SHIFT
	SHIFT
	SET /A files_offset+=2
	GOTO :parse_params_loop
)
IF [%1]==[--vdub] (
	SET VDUB=%~2
	SHIFT
	SHIFT
	SET /A files_offset+=2
	GOTO :parse_params_loop
)
IF [%1]==[--upscale] (
	SET UPSCALE=%~2
	SHIFT
	SHIFT
	SET /A files_offset+=2
	GOTO :parse_params_loop
)
IF [%1]==[--deshaker] (
	SET DESHAKER=%~2
	SHIFT
	SHIFT
	SET /A files_offset+=2
	GOTO :parse_params_loop
)
IF [%1]==[--deshaker-log] (
	SET DESHAKER_LOG=%~2
	SHIFT
	SHIFT
	SET /A files_offset+=2
	GOTO :parse_params_loop
)
IF [%1]==[--output-dir] (
	SET OUTPUT_DIR=%~2
	SHIFT
	SHIFT
	SET /A files_offset+=2
	GOTO :parse_params_loop
)
IF [%1]==[--output-suffix] (
	SET OUTPUT_SUFFIX=%~2
	SHIFT
	SHIFT
	SET /A files_offset+=2
	GOTO :parse_params_loop
)
IF [%1]==[--delete-src] (
	SET DELETE_SRC=TRUE
	SHIFT
	SET /A files_offset+=1
	GOTO :parse_params_loop
)
IF [%1]==[--mode] (
	SET MODE=%2
	SHIFT
	SHIFT
	SET /A files_offset+=2
	GOTO :parse_params_loop
)
IF [%1]==[--codec] (
	SET CODEC=%~2
	SHIFT
	SHIFT
	SET /A files_offset+=2
	GOTO :parse_params_loop
)
IF [%1]==[--codec-preset] (
	SET CODEC_PRESET=%~2
	SHIFT
	SHIFT
	SET /A files_offset+=2
	GOTO :parse_params_loop
)
IF [%1]==[--codec-temp] (
	SET CODEC_TEMP=%~2
	SHIFT
	SHIFT
	SET /A files_offset+=2
	GOTO :parse_params_loop
)
IF [%1]==[--codec-temp-preset] (
	SET CODEC_TEMP_PRESET=%~2
	SHIFT
	SHIFT
	SET /A files_offset+=2
	GOTO :parse_params_loop
)
:parse_params_loop_end
CALL :debug parse_params_loop_end
CALL :debug Files offset: %files_offset%

:parse_params_files_loop
IF NOT [%1]==[] (
	SET /A files_count+=1
	SET /A files_size+=%~z1
	SET /A files_size_mb+=%~z1/1048576
	SHIFT
	GOTO :parse_params_files_loop
)

CALL :debug Total files count: %files_count%
CALL :debug Total files size: %files_size% (%files_size_mb%)

GOTO :EOF


